from paramiko import SSHClient, SFTPClient, AutoAddPolicy
from pathlib import Path
import sys


def upload(host, username, password, project_path, remote_path='.'):
    with SSHClient() as ssh:
        ssh.set_missing_host_key_policy(AutoAddPolicy())
        ssh.connect(hostname=host, username=username, password=password)
        with SFTPClient.from_transport(ssh.get_transport()) as sftp:
            _transferring(ssh, sftp, Path(project_path), remote_path)
    return 'Successful!'


def _transferring(ssh, sftp, file_path, root_path):
    root_path = f'{root_path}/{file_path.name}'
    if file_path.is_dir():
        ssh.exec_command(f'mkdir -p {root_path}')[1].read()
        for f in file_path.iterdir():
            _transferring(ssh, sftp, file_path / f.name, root_path)
    else: sftp.put(file_path, root_path)


def put():
    params = sys.argv[1:]
    if len(params) == 4: host, username, password, remote_path = params
    elif len(params) == 3:
        host, username, password = params
        remote_path = '.'
    else: return 'Error: please check the command (propor <host> <username> <password> <remote_path=".">).'
    return upload(host, username, password, Path.cwd(), remote_path)



from paramiko import SSHClient, SFTPClient, AutoAddPolicy
from pathlib import Path
import sys


def download(host, username, password, local_path, remote_path):
    with SSHClient() as ssh:
        ssh.set_missing_host_key_policy(AutoAddPolicy())
        ssh.connect(hostname=host, username=username, password=password)
        with SFTPClient.from_transport(ssh.get_transport()) as sftp:
            _transferring(sftp, remote_path, local_path)
    return 'Successful!'


def _transferring(sftp, file_path, root_path):
    file_name = file_path.split('/')[-1]
    root_path = root_path / file_name
    if '.' in file_name: sftp.get(file_path, root_path)
    else:
        Path(root_path).mkdir(parents=True, exist_ok=True)
        files = sftp.listdir(file_path)
        for f in files: _transferring(sftp, f'{file_path}/{f}', root_path)


def get():
    params = sys.argv[1:]
    if len(params) == 4: host, username, password, remote_path = params
    else: return 'Error: please check the command (propor-get <host> <username> <password> <remote_path>).'
    return download(host, username, password, Path.cwd(), remote_path)



import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='propor',
    version='2019.4.24',
    author='Czw_96',
    author_email='459749926@qq.com',
    description='Project porter.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/Czw96/propor',
    packages=setuptools.find_packages(exclude=('trash',)),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    entry_points={
        'console_scripts': ['propor-get=propor.get:get', 'propor-put=propor.put:put'],
    },
    install_requires=[
        'paramiko',
    ],
)
